@@ -20,6 +20,11 @@ sub match {
 
 sub text { '/' };
 
+sub str {
+    my ($self) = @_;
+    '/' . ($self->{-tail} ? $self->{-tail}->str : '');
+}
+
 1;
 
 __END__
