@@ -24,17 +24,6 @@ sub text { '.' }
 
 __END__
 
-=head1 NAME
-
-Config::Maker::Path::This - FIXME
-
-=head1 SYNOPSIS
-
-  use Config::Maker::Path::This
-FIXME
-
-=head1 DESCRIPTION
-
 =head1 AUTHOR
 
 Jan Hudec <bulb@ucw.cz>
@@ -46,9 +35,5 @@ Copyright 2004 Jan Hudec. All rights reserved.
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=head1 SEE ALSO
-
-configit(1), perl(1), Config::Maker(3pm).
-
 =cut
 # arch-tag: cea107ac-1f38-467e-b0e1-3bb978a56893
