@@ -18,6 +18,7 @@ use overload
     fallback => 1;
 
 our $root;
+our $meta;
 our $repository;
 our %checks;
 
@@ -26,6 +27,11 @@ sub root {
     $root;
 }
 
+# Get special meta content ('//' special type)
+sub meta {
+    $meta;
+}
+
 # Get repository context ('*' special type). The repository is a special type
 # where types for reuse are stored:
 sub repository {
@@ -167,6 +173,12 @@ $root = __PACKAGE__->new(
     format => [],
 ); # Default context (in repository only) should work here...
 
+# And last but not least the meta type...
+$meta = __PACKAGE__->new(
+    name => '//',
+    format => [],
+); # Default context (in repository only) should work here too...
+
 # Checking functions:
 
 sub _findtimes {
